@@ -140,6 +140,7 @@
 #' @examples
 #' \donttest{
 #' ## These are long running examples that use parallel computing!
+#' # Running all the below examples will take approximately 3-4 minutes.
 #'
 #' # These examples use the data 'eurusd' which comes with the
 #' # package, but in a scaled form (similar to Kalliovirta et al. 2016).
@@ -156,56 +157,40 @@
 #' print_std_errors(fit12)
 #' profile_logliks(fit12)
 #'
+#' # The rest of the examples only use a single estimation round with a given
+#' # seed that produces the MLE to reduce running time of the examples. When
+#' # estimating models for empirical applications, a large number of estimation
+#' # rounds (ncalls = a large number) should be performed to ensure reliability
+#' # of the estimates.
+#'
 #' # Structural GMVAR(1,2) model identified with sign
 #' # constraints.
 #' W_122 <- matrix(c(1, 1, -1, 1), nrow=2)
 #' fit12s <- fitGMVAR(data, p=1, M=2, structural_pars=list(W=W_122),
-#'   ncalls=16, seeds=1:16, ncores=4)
+#'   ncalls=1, seeds=1)
 #' fit12s
 #'
 #' # Structural GMVAR(2, 2) model identified statistically only
 #' W_222 <- matrix(c(1, NA, 1, NA), nrow=2)
 #' fit22s <- fitGMVAR(data, p=2, M=2, structural_pars=list(W=W_222),
-#'   ncalls=16, seeds=1:16, ncores=4)
-#' fit22s
-#'
-#' # GMVAR(2,2) model with mean parametrization
-#' fit22 <- fitGMVAR(data, p=2, M=2, parametrization="mean",
-#'                   ncalls=20, seeds=1:20, ncores=4)
-#' fit22
-#'
-#' # Structural GMVAR(2,2) model with the lambda parameters restricted
-#' # to be identical (in the second regime) and the shocks identified
-#' # with diagonal of the B-matrix normalized positive and one zero constraint.
-#' # The resulting model has error term covariance matrices that are
-#' # multiplicatives of each other, while the identification equals to
-#' # identification through Cholesky decomposition.
-#' W_222 <- matrix(c(1, NA, 0, 1), nrow=2)
-#' C_lambda_222 <- matrix(c(1, 1), nrow=2)
-#' fit22s <- fitGMVAR(data, p=2, M=2, structural_pars=list(W=W_222, C_lambda=C_lambda_222),
-#'   ncalls=20, seeds=1:20)
+#'   ncalls=1, seeds=12)
 #' fit22s
 #'
 #' # GMVAR(2,2) model with autoregressive parameters restricted
 #' # to be the same for both regimes
 #' C_mat <- rbind(diag(2*2^2), diag(2*2^2))
-#' fit22c <- fitGMVAR(data, p=2, M=2, constraints=C_mat)
+#' fit22c <- fitGMVAR(data, p=2, M=2, constraints=C_mat, ncalls=1, seeds=1)
 #' fit22c
 #'
-#' # GMVAR(2,2) model with autoregressive parameters and the mean
-#' # parameters restricted to be the same for both regimes
-#' # (only the covariance matrix varies)
-#' fit22cm <- fitGMVAR(data, p=2, M=2, parametrization="mean",
-#'  constraints=C_mat, same_means=list(1:2), ncores=4, ncalls=16)
-#'
 #' # GMVAR(2,2) model with autoregressive parameters restricted
-#' # to be the same for both regimes and non-diagonl elements
+#' # to be the same for both regimes and non-diagonal elements
 #' # the coefficient matrices constrained to zero. Estimation
 #' # with only 10 estimation rounds.
 #' tmp <- matrix(c(1, rep(0, 10), 1, rep(0, 8), 1, rep(0, 10), 1),
 #'  nrow=2*2^2, byrow=FALSE)
 #' C_mat2 <- rbind(tmp, tmp)
-#' fit22c2 <- fitGMVAR(data, p=2, M=2, constraints=C_mat2)
+#' fit22c2 <- fitGMVAR(data, p=2, M=2, constraints=C_mat2,
+#'                     ncalls=1, seeds=3)
 #' fit22c2
 #' }
 #' @export
@@ -217,7 +202,7 @@ fitGMVAR <- function(data, p, M, conditional=TRUE, parametrization=c("intercept"
   on.exit(closeAllConnections())
   if(!all_pos_ints(c(p, M, ncalls, ncores, maxit))) stop("Arguments p, M, ncalls, ncores, and maxit must be positive integers")
   stopifnot(length(ncalls) == 1)
-  if(!is.null(seeds) && length(seeds) != ncalls) stop("The argument 'seeds' needs be NULL or a vector of length 'ncalls'")
+  if(!is.null(seeds) && length(seeds) != ncalls) stop("The argument 'seeds' should be NULL or a vector of length 'ncalls'")
   parametrization <- match.arg(parametrization)
   data <- check_data(data=data, p=p)
   d <- ncol(data)
@@ -356,6 +341,7 @@ fitGMVAR <- function(data, p, M, conditional=TRUE, parametrization=c("intercept"
 #' @examples
 #' \donttest{
 #' ## These are long running examples that use parallel computing!
+#' ## Running the below examples takes approximately 2 minutes
 #'
 #' # These examples use the data 'eurusd' which comes with the
 #' # package, but in a scaled form.
@@ -364,44 +350,12 @@ fitGMVAR <- function(data, p, M, conditional=TRUE, parametrization=c("intercept"
 #'
 #' # GMVAR(1,2) model, only 5 iterations of the variable metric
 #' # algorithm
-#' fit12 <- fitGMVAR(data, p=1, M=2, maxit=5)
+#' fit12 <- fitGMVAR(data, p=1, M=2, ncalls=1, maxit=5, seeds=7)
 #' fit12
 #'
 #' # Iterate more:
 #' fit12_2 <- iterate_more(fit12)
 #' fit12_2
-#'
-#' # Structural GMVAR(1,2) model identified with sign
-#' # constraints. Only 10 iterations of the variable metric
-#' # algorithm
-#' W_122 <- matrix(c(1, -1, 1, 1), nrow=2)
-#' fit12s <- fitGMVAR(data, p=1, M=2, structural_pars=list(W=W_122),
-#'   ncalls=16, maxit=10, seeds=1:16)
-#' fit12s
-#'
-#' # Iterate more:
-#' fit12s_2 <- iterate_more(fit12s)
-#' fit12s_2
-#'
-#' # GMVAR(2,2) model with autoregressive parameters restricted
-#' # to be the same for all regimes, only 10 iterations of the
-#' # variable metric algorithm
-#' C_mat <- rbind(diag(2*2^2), diag(2*2^2))
-#' fit22c <- fitGMVAR(data, p=2, M=2, constraints=C_mat, maxit=10)
-#' fit22c
-#'
-#' # Iterate more:
-#' fit22c_2 <- iterate_more(fit22c)
-#' fit22c_2
-#'
-#' # GMVAR(3,2) model, only 10 iterations of the variable metric
-#' # algorithm
-#' fit32 <- fitGMVAR(data, p=3, M=2, maxit=10)
-#' fit32
-#'
-#' # Iterate more:
-#' fit32_2 <- iterate_more(fit32)
-#' fit32_2
 #' }
 #' @export
 
